<?php

namespace Shopping\Inquiry\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Inquiry\Models\Inquiry;

class InquiryPolicy
{

    /**
     * Determine if the given user can view the inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function view(UserPolicy $user, Inquiry $inquiry)
    {
        if ($user->canDo('inquiry.inquiry.view') && $user->isAdmin()) {
            return true;
        }

        return $inquiry->user_id == user_id() && $inquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can create a inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('inquiry.inquiry.create');
    }

    /**
     * Determine if the given user can update the given inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function update(UserPolicy $user, Inquiry $inquiry)
    {
        if ($user->canDo('inquiry.inquiry.edit') && $user->isAdmin()) {
            return true;
        }

        return $inquiry->user_id == user_id() && $inquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Inquiry $inquiry)
    {
        return $inquiry->user_id == user_id() && $inquiry->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Inquiry $inquiry)
    {
        if ($user->canDo('inquiry.inquiry.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given inquiry.
     *
     * @param UserPolicy $user
     * @param Inquiry $inquiry
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Inquiry $inquiry)
    {
        if ($user->canDo('inquiry.inquiry.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
